@@ -95,9 +95,6 @@
 /* do we have OPIE for server-side OTP support? */
 #undef HAVE_OPIE
 
-/* should we support otp_setpass */
-#undef DO_OTP_SETPASS
-
 /* Do we have kerberos for plaintext password checking? */
 #undef HAVE_KRB
 
@@ -221,7 +218,9 @@ struct iovec {
 #endif
 
 /* Make Linux happy... */
+#ifndef _GNU_SOURCE
 #define _GNU_SOURCE
+#endif
 
 #ifndef HAVE___ATTRIBUTE__
 /* Can't use attributes... */
