@@ -1,7 +1,7 @@
 /* SASL server API implementation
  * Rob Siemborski
  * Tim Martin
- * $Id: checkpw.c,v 1.44 2001/12/06 22:27:27 rjs3 Exp $
+ * $Id: checkpw.c,v 1.49 2002/03/07 19:14:04 ken3 Exp $
  */
 /* 
  * Copyright (c) 2001 Carnegie Mellon University.  All rights reserved.
@@ -100,7 +100,7 @@ extern int errno;
  * where <secret> = MD5(<salt>, "sasldb", <pass>)
  */
 static int _sasl_make_plain_secret(const char *salt, 
-				   const char *passwd, int passlen,
+				   const char *passwd, size_t passlen,
 				   sasl_secret_t **secret)
 {
     MD5_CTX ctx;
@@ -172,7 +172,7 @@ static int auxprop_verify_password(sasl_conn_t *conn,
          || !auxprop_values[0].values || !auxprop_values[0].values[0])
        && (!auxprop_values[1].name
          || !auxprop_values[1].values || !auxprop_values[1].values[0]))
-	    return SASL_FAIL;
+	    return SASL_NOUSER;
         
     /* It is possible for us to get useful information out of just
      * the lookup, so we won't check that we have a password until now */
@@ -195,7 +195,8 @@ static int auxprop_verify_password(sasl_conn_t *conn,
 	const char *db_secret = auxprop_values[1].values[0];
 	sasl_secret_t *construct;
 	
-	ret = _sasl_make_plain_secret(db_secret, passwd, strlen(passwd),
+	ret = _sasl_make_plain_secret(db_secret, passwd,
+				      strlen(passwd),
 				      &construct);
 	if (ret != SASL_OK) {
 	    goto done;
@@ -415,7 +416,7 @@ static int pwcheck_verify_password(sasl_conn_t *conn,
  * Keep calling the read() system call with 'fd', 'buf', and 'nbyte'
  * until all the data is read in or an error occurs.
  */
-int retry_read(int fd, void *buf, unsigned nbyte)
+static int retry_read(int fd, void *buf, unsigned nbyte)
 {
     int n;
     int nread = 0;
@@ -550,7 +551,7 @@ static int saslauthd_verify_password(sasl_conn_t *conn,
       return SASL_OK;
   
     response[count] = '\0';
-    sasl_seterror(conn, 0, "authentication failed");
+    sasl_seterror(conn, SASL_NOLOG, "authentication failed");
     return SASL_BADAUTH;
 }
 
