@@ -1,7 +1,7 @@
 /* CRAM-MD5 SASL plugin
  * Rob Siemborski
  * Tim Martin 
- * $Id: cram.c,v 1.61 2001/12/07 03:22:56 rjs3 Exp $
+ * $Id: cram.c,v 1.63 2002/01/21 21:04:49 rjs3 Exp $
  */
 /* 
  * Copyright (c) 2001 Carnegie Mellon University.  All rights reserved.
@@ -515,7 +515,7 @@ static sasl_server_plug_t crammd5_server_plugins[] =
     "CRAM-MD5",
     0,
     SASL_SEC_NOPLAINTEXT | SASL_SEC_NOANONYMOUS,
-    0,
+    SASL_FEAT_SERVER_FIRST,
     NULL,
     &crammd5_server_mech_new,
     &crammd5_server_mech_step,
@@ -798,6 +798,11 @@ static int crammd5_client_mech_step(void *conn_context,
   {     
     sasl_security_properties_t secprops;
     unsigned int external;
+    char *in16;
+    int result;
+    int auth_result=SASL_OK;
+    int pass_result=SASL_OK;
+    int maxsize;
 
     *clientout=NULL;
     *clientoutlen=0;
@@ -807,25 +812,11 @@ static int crammd5_client_mech_step(void *conn_context,
     external=params->external_ssf;
 
     if (secprops.min_ssf>0+external) {
-	SETERROR( params->utils, "whoops! looks like someone wanted SSF out of the CRAM plugin");
+	SETERROR( params->utils,
+		  "whoops! looks like someone wanted SSF out of the CRAM plugin");
 	return SASL_TOOWEAK;
     }
 
-    text->state=2;
-
-    /* (server always goes first for CRAM) */
-    if(serverinlen == 0)
-	return SASL_CONTINUE;
-  }
-
-  if (text->state==2)
-  {
-    char *in16;
-    int result;
-    int auth_result=SASL_OK;
-    int pass_result=SASL_OK;
-    int maxsize;
-
     /* try to get the userid */
     if (text->authid==NULL)
     {
@@ -925,7 +916,7 @@ static sasl_client_plug_t crammd5_client_plugins[] =
     "CRAM-MD5",
     0,
     SASL_SEC_NOPLAINTEXT | SASL_SEC_NOANONYMOUS,
-    0,
+    SASL_FEAT_SERVER_FIRST,
     NULL,
     NULL,
     &crammd5_client_mech_new,
